/**
 * GarrySeldon - garryseldon@yande.ru
 * Класс для создания модалок
 * https://getbootstrap.com/docs/5.0/components/modal/ 
 */

class Bootbox2 {

    modal;
    modalHtml;

    constructor(params = {}) {
        let self = this;
        let paramsDefault = {
            title: null, //Заголовок
            message: 'Вы уверены?',
            size: null,   //Размер окна (modal-sm, modal-lg, modal-xl) 
            closeButton: true, //Крестик закрытия в углу
            removeAfter: true,  //Удалить всю модалку после закрытия
            animation: true, //fade - анимация 
            startShow: true, //Паказывать окно сразу
            buttons: [
                {
                    label: 'Ок',
                    className: 'btn btn-primary',
                    callback: function () {
                        self.close();
                    }
                }
            ]
        };
        let options = Object.assign(paramsDefault, params); 
        this.createModal(options);
    }

    createModal(params) {

        let self = this;
        let modal = document.createElement('div');
        modal.className = 'modal';
        if (params.animation) {
            modal.classList.add('fade');
        }
        modal.setAttribute('aria-hidden', 'true');
        modal.setAttribute('tabindex', '-1');

        let d = document.createElement('div');
        d.className = 'modal-dialog';
        if (params.size) {
            d.classList.add(params.size);
        }
        modal.appendChild(d); 

        let c = document.createElement('div');
        c.className = 'modal-content';
        d.appendChild(c);  
        
        let h = null;
        if (params.title) {
            h = document.createElement('div');
            h.className = 'modal-header';
            c.appendChild(h);
        
            let h5 = document.createElement('h5');
            h5.className = 'modal-title';
            h5.innerHTML = params.title;
            h.appendChild(h5);     
        }


        let b = document.createElement('div');
        b.className = 'modal-body';
        b.innerHTML = params.message;
        this.body = b;
        c.appendChild(b);

        if (params.closeButton) {
            let btnClose = document.createElement('button');
            btnClose.addEventListener('click', e => { self.close(); });
            btnClose.className = 'btn-close';            
            if (h) {
                h.appendChild(btnClose);
            }
        }

        if (params.buttons) {
            let f = document.createElement('div');
            f.className = 'modal-footer';
            c.appendChild(f);

            params.buttons.forEach(btn => {
                let b = document.createElement('button');
                b.className = btn.className !== undefined ? btn.className : 'btn btn-primary';
                b.innerHTML = btn.label !== undefined ? btn.label : 'Ок';
                let callback = btn.callback !== undefined ? btn.callback : function() { self.close(); };
                b.addEventListener('click', callback);
                f.appendChild(b);         
            });
        }

        document.body.append(modal);

        this.modalHtml = modal;
        this.modal = new bootstrap.Modal(modal, {focus: true});

        if (params.removeAfter) {
            this.modalHtml.addEventListener('hidden.bs.modal', function (event) {
                self.removeModal();
            });
        }

        if (params.startShow) {
            this.show();
        }
    }

    show() {    
        this.modal.show();
    }

    toggle() {
        this.modal.toggle();
    }

    close() {
        this.modal.hide();
    }

    removeModal() {
        this.modalHtml.remove();
    }

    writeMessage(html) {
        this.body.innerHTML = html;
    }
}